3.35.12 (2022-11-15)
====================
👷 Bug fixes
------------

- hook: correct a typo, self.warn doesn't exist

3.35.11 (2022-10-04)
====================
👷 Bug fixes
------------

- attr: when an entity is not existing always return None when fetching its attributes (#599)
- web.views: escape text from the undohistory view (#598)

🤷 Various changes
------------------

- delete unused translations from \*.po files (#600)
- skeleton: add `long_description_content_type` in setup.py

3.35.10 (2022-09-22)
====================
👷 Bug fixes
------------

- startup_views: raise AuthenticationError if anon access is disabled on
  StartupView (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/595)

3.35.9 (2022-09-14)
===================
👷 Bug fixes
------------

- bookmark: do not escape the xaddrelation view from ajaxedit module

3.35.8 (2022-08-30)
===================
👷 Bug fixes
------------

- pyramid: Redirect to the wanted URL after a successfully loggedin (to #584)
- xss: Ensure to use the xml_escape method on entity attributes
- perf: Restore initial performances by removing the uneccessary join

3.35.7 (2022-07-21)
===================
👷 Bug fixes
------------

- schema_exporters: handle symmetrical relation in schema export. (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/568)

🤷 Various changes
------------------

- feat(markdown)!: update Mardown version to 3.4 and rewrite urlize extension (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/569)

3.35.6 (2022-07-13)
===================
🤷 Various changes
------------------

- fix warnings of yams 0.48+ (3.35 requires <0.48)

3.35.5 (2022-07-13)
===================

👷 Bug fixes
------------

- basecontrollers: str object have no more "decode" method since py3
- fix some warnings of yams 0.48+
- htmlwidgets: BoxLink rendering is broken
- server: remove a memory leak related to a file
- test: improve one related to CSRF

3.35.4 (2022-06-03)
===================
👷 Bug fixes
------------

- pyramid: adapt TestApp.put_json method to CSRF

3.35.3 (2022-06-01)
===================
🎉 New features
---------------

- pkg: upgrade version of waitress to 2.1.1 or more, for security reason. (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/543)

👷 Bug fixes
------------

- base64.decodestring is deprecated and has been removed
- pyramid: adapt TestApp.post_json method to CSRF
- pyramid: try to get "/login" if "/" is forbidden

3.35.2 (2022-03-31)
===================
👷 Bug fixes
------------

- rql2sql: upgrade RQL version to fix translation of ``NOT EXISTS(X eid Y)`` (`#528 <https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/528>`_)
- view: don't escape html tags inside image previews

3.35.1 (2022-03-09)
===================

- avoid excaping cubicweb:loadurl's value twice (to `#523 <https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/523>`_)
- don't escape whole key="value" attributes in TreeViewItemView (to `#523 <https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/523>`_)
- escape URLs passed as href attributes (to `#523 <https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/523>`_)

3.35 (2022-02-02)
=================
Breaking changes
----------------

- deprecate RQLSuggestionsBuilder component ; users of this component should
  now use ``rqlsuggestions.RQLSuggestionsBuilder`` instead. RQL bar completion
  behaviour can be changed by replacing the "rql_suggest" ajax function. If
  this function isn't registered, rql completion is disabled.
- remove RQLNoSuggestionsBuilder
- disable login using GET requests for security reasons
- web: remove support of old Internet Explorer versions: ``add_css`` no longer
  accepts ``iespec`` and ``ieonly`` arguments

🎉 New features
---------------

- add a Dockerfile in the skeleton
- add a function for deleting entities faster
- config: add help messages in configuration files (all-in-one and sources)
- disable constraints checks on the DB upon deletion
- show cube name when there is a version conflict
- skeleton: add release-new in skeleton
- upgrade to `yams 0.47 <https://forge.extranet.logilab.fr/open-source/yams/-/blob/branch/default/CHANGELOG.md#version-0470-2022-01-14>`_
- content negociation: we now can use ``/<etype>/<rest_attr>`` route for content
  negociation, if rest_attr is defined, the route ``/<etype>/<rest_attr>`` is
  disabled for content negociation in this situation

👷 Bug fixes
------------

- relation_type not existing in some conditions on RelationDefinition
  (ionDefinition.rtype has been deprecated in yams in favor of
  relation_type)

🤖 Continuous integration
-------------------------

- only collect warnings when running tests on the default branch (`#489 <https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/489>`_)
